#ifndef _demoninit_h
#define _demoninit_h

void demoninit();


#endif // _demoninit_h
